﻿<#
Prequisites:
    - Install Waldo's Cloud Ready Software PowerShell modules 
        https://github.com/waldo1001/Cloud.Ready.Software.PowerShell
    - NAV installed manually in NA version
    - SQL Backup file for the product, developed in NAV W1
    - SQL Backup file for standard NAV W1
    - a valid NAV developer license that includes insert rights for the product number range
    NOTE: All environments should be in the same build number

This script will:
    - step 1: Create a copy of the NA environment
    - step 2: Create a standard W1 environment
    - step 3: Create a product W1 environment

Standard W1 will act as the ORIGINAL environment
Product W1 will act as the MODIFIED environment
Standard NA will act as the TARGET environment
Product NA will act as the RESULT environment

NOTE: This script is provided "AS IS" without any guarantees, warranties, or support

#>

$WorkingFolder = 'C:\Work'
if (-not(Test-Path $WorkingFolder)) {New-Item -ItemType Directory -Path $WorkingFolder}
Set-Location $WorkingFolder

$DBServer = 'KERPLUNK'
$EnvOriginal = 'NAV2017W1CU2'
$EnvModified = 'NAV2017W1CU2-PROD'
$EnvTarget = 'NAV2017NACU2'
$EnvResult = 'NAV2017NACU2-PROD'

$OriginalBackupFile = Join-Path $WorkingFolder "Backups\NAV2017W1CU2.bak"
$ModifiedBackupFile = Join-Path $WorkingFolder "Backups\NAV2017W1-Product.bak"
$LicenseFile = Join-Path $WorkingFolder '2017DEV.flf'

# Step 1 - The TARGET environment is in this case a standard NAV2017 CU2 NA database
#          The RESULT environment starts as an identical copy of the TARGET environment
#          They will be used as the TARGET and RESULT environments to create the merged objects
Copy-NAVEnvironment -ServerInstance $EnvTarget -ToServerInstance $EnvResult

# Step 2 - The ORIGINAL environment is in this case a standard NAV2017 CU2 W1 database
#          This is used as the ORIGINAL environment to create the merged objects
New-NAVEnvironment `
    -BackupFile $OriginalBackupFile `
    -ServerInstance $EnvOriginal `
    -Databasename $EnvOriginal `
    -LicenseFile $LicenseFile `
    -EnablePortSharing

# Step 3 - The MODIFIED environment is in this case a product database, which was based on NAV2017 CU2 W1
#          This is used as the MODIFIED environment to create the merged objects
New-NAVEnvironment `
    -BackupFile $ModifiedBackupFile `
    -ServerInstance $EnvModified `
    -Databasename $EnvModified `
    -LicenseFile $LicenseFile `
    -EnablePortSharing





